@@ -4,31 +4,38 @@
 #'
 #' @return A data frame of all available MODIS Land Products Subsets products
 #' @keywords MODIS Land Products Subsets, products, meta-data
+#' @seealso \code{\link[MODISTools]{mt_bands}}
+#' \code{\link[MODISTools]{mt_sites}} \code{\link[MODISTools]{mt_dates}}
 #' @export
+#' @importFrom memoise memoise
 #' @examples
 #'
 #' \donttest{
 #' # list all available MODIS Land Products Subsets products
 #' products <- mt_products()
-#' print(products)
+#' head(products)
 #'}
+#'
 
-mt_products <- function(){
+mt_products <- memoise::memoise(function(){
 
-  # define server settings (main server should become global
-  # as in not specified in every function)
-  server <- "https://modis.ornl.gov/rst/"
-  end_point <- "api/v1/products"
-  url <- paste0(server,end_point)
+  # define url
+  url <- paste(mt_server(), "products", sep = "/")
 
   # try to download the data
-  products <- try(jsonlite::fromJSON(url))
+  products <- try(jsonlite::fromJSON(url))$products
 
   # trap errors on download, return a general error statement
   if (inherits(products, "try-error")){
     stop("Your requested timed out or the server is unreachable")
   }
 
+  # convert labels to more sensible names
+  products$frequency <- gsub("-", " ", products$frequency)
+  products$frequency <- gsub("Day", "day", products$frequency)
+  products$frequency <- gsub("Daily", "1 day", products$frequency)
+  products$frequency <- gsub("Yearly", "1 year", products$frequency)
+
   # return a data frame with all products and their details
-  return(products$products)
-}
+  return(products)
+})
